==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/AlignLinearGraphLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatLinearGraphLabelEventArgsDescriptionMetadata } from "./FormatLinearGraphLabelEventArgsDescriptionMetadata";
import { AlignLinearGraphLabelEventArgsDescription } from "./AlignLinearGraphLabelEventArgsDescription";
/**
 * @hidden
 */
export let AlignLinearGraphLabelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AlignLinearGraphLabelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AlignLinearGraphLabelEventArgsDescriptionMetadata.a == null) {
                AlignLinearGraphLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AlignLinearGraphLabelEventArgsDescriptionMetadata.c(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
            }
            if (a.k(AlignLinearGraphLabelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            FormatLinearGraphLabelEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            AlignLinearGraphLabelEventArgsDescriptionMetadata.b(a);
            a.ad("AlignLinearGraphLabelEventArgs", () => new AlignLinearGraphLabelEventArgsDescription());
            a.ac("AlignLinearGraphLabelEventArgs", AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
    }
    AlignLinearGraphLabelEventArgsDescriptionMetadata.$t = markType(AlignLinearGraphLabelEventArgsDescriptionMetadata, 'AlignLinearGraphLabelEventArgsDescriptionMetadata');
    AlignLinearGraphLabelEventArgsDescriptionMetadata.a = null;
    return AlignLinearGraphLabelEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/AlignLinearGraphLabelEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FormatLinearGraphLabelEventArgsDescriptionMetadata } from "./FormatLinearGraphLabelEventArgsDescriptionMetadata";
import { AlignLinearGraphLabelEventArgsDescription } from "./AlignLinearGraphLabelEventArgsDescription";
/**
 * @hidden
 */
export let AlignLinearGraphLabelEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class AlignLinearGraphLabelEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (AlignLinearGraphLabelEventArgsDescriptionMetadata.a == null) {
                AlignLinearGraphLabelEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AlignLinearGraphLabelEventArgsDescriptionMetadata.c(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
            }
            if (a.k(AlignLinearGraphLabelEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            FormatLinearGraphLabelEventArgsDescriptionMetadata.c(a);
        }
        static d(a) {
            AlignLinearGraphLabelEventArgsDescriptionMetadata.b(a);
            a.ae("AlignLinearGraphLabelEventArgs", () => new AlignLinearGraphLabelEventArgsDescription());
            a.ad("AlignLinearGraphLabelEventArgs", AlignLinearGraphLabelEventArgsDescriptionMetadata.a);
        }
    }
    AlignLinearGraphLabelEventArgsDescriptionMetadata.$t = markType(AlignLinearGraphLabelEventArgsDescriptionMetadata, 'AlignLinearGraphLabelEventArgsDescriptionMetadata');
    AlignLinearGraphLabelEventArgsDescriptionMetadata.a = null;
    return AlignLinearGraphLabelEventArgsDescriptionMetadata;
})();
